<?php
/**
 * @version     3.2.0
 * @package     com_secretary
 *
 * @author       Fjodor Schaefer (schefa.com)
 * @copyright    Copyright (C) 2015-2017 Fjodor Schaefer. All rights reserved.
 * @license      MIT License
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 */

namespace Secretary;

use JFactory;
use JString;
use JRoute;

// No direct access
defined('_JEXEC') or die;

class Route
{
    
    public static function create( $view = '', $fields = array() )
    {
        $url = 'index.php?option=com_secretary';
        
        if(!empty($view))
            $url .= '&view='.$view;
        
        if(!empty($fields)) {
            foreach($fields AS $key => $value) {
                if(!empty($key) || !empty($value)) {
                    $url .= "&". $key ."=". $value;
                }
            }
        }
        
        return JRoute::_($url, false);
    }
    
    public static function safeURL($string)
    {
        // Remove any '-' from the string since they will be used as concatenaters
        $str = str_replace('-', ' ', $string);
        
        $lang = JFactory::getLanguage();
        $str = $lang->transliterate($str);
        
        // Trim white spaces at beginning and end of alias and make lowercase
        $str = trim(JString::strtolower($str));
        
        // Remove any duplicate whitespace, and ensure all characters are alphanumeric
        $str = preg_replace('/(\s|[^A-Za-z0-9\-])+/', '-', $str);
        
        // Trim dashes at beginning and end of alias
        $str = trim($str, '-');
        
        return $str;
    }
}

